//+------------------------------------------------------------------+
//|                                       PositionSizeCalculator.mq4 |
//|                             Copyright  2012-2015, Andriy Moraru |
//+------------------------------------------------------------------+
#property copyright "Copyright  2012-2015, Andriy Moraru"
#property link      "http://www.earnforex.com"
#property version   "1.22"

#property description "Calculates position size based on account balance/equity,"
#property description "currency, currency pair, given entry level, stop-loss level"
#property description "and risk tolerance (set either in percentage points or in base currency)."
#property description "Can display reward/risk ratio based on take-profit."
#property description "Can also show total portfolio risk based on open trades and pending orders."
#property description "2015-04-08, ver. 1.22 - added line height parameter, minor bug fixes."
// 2015-04-04, ver. 1.21 - fixed line width bug.
// 2015-03-19, ver. 1.20 - added input parameters to hide some lines.
// 2015-03-08, ver. 1.19 - commission support, minor bug fixes.
// 2015-02-27, ver. 1.18 - two indicator versions - Separate or Main window.
// 2015-02-16, ver. 1.17 - separate window, input/output values, more warnings.
// 2015-02-13, ver. 1.16 - margin, warnings, number formatting, rounding down.
// 2015-01-30, ver. 1.15 - values read from lines are now rounded. DeleteLines also clears old lines when attaching.
// 2014-12-19, ver. 1.14 - fixed minor bug when restarting MT4; also, lines are no longer hidden from object list.
// 2014-10-03, ver. 1.13 - added portfolio risk calculation.
// 2014-09-17, ver. 1.12 - position size is now rounded down.
// 2014-04-11, ver. 1.11 - added potential reward display and color/style input parameters.
// 2013-11-11, ver. 1.10 - added optional Ask/Bid tracking for Entry line.
// 2013-02-11, ver. 1.8 - completely revamped calculation process.
// 2013-01-14, ver. 1.7 - fixed "division by zero" error.
// 2012-12-10, ver. 1.6 - will use local values if both Entry and SL are missing.
// 2012-11-02, ver. 1.5 - a more intelligent name prefix/postfix detection.
// 2012-10-13, ver. 1.4 - fixed contract size in lot size calculation.
// 2012-10-13, ver. 1.3 - proper lot size calculation for gold, silver and oil.
// 2012-09-29, ver. 1.2 - improved account currency and reference pair detection.
// 2012-05-10, ver. 1.1 - added support for setting risk in money.
#property description "WARNING: There is no guarantee that the output of this indicator is correct. Use at your own risk."

#property indicator_separate_window

#include "PositionSizeCalculator_Base.mqh"
extern int MaxNumberLength = 14; // How many digits will there be in numbers as maximum?
extern int second_column_x = 400;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   IndicatorShortName("Position Size Calculator");
   EventSetTimer(1);
   return(0);
}

//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
{
   ObjectsDeleteAll(Window, OBJ_LABEL);
   
   if (DeleteLines)
   {
      ObjectDelete(0, "EntryLine");
      ObjectDelete(0, "StopLossLine");
      if (TakeProfitLevel > 0) ObjectDelete(0, "TakeProfit");
   }

   return(0);
}